==> android-4.0.1.2-sources.jar: android/widget/AbsSeekBar.java <==
package android.widget;
public abstract class AbsSeekBar
  extends android.widget.ProgressBar
{
public  AbsSeekBar(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AbsSeekBar(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AbsSeekBar(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setThumb(android.graphics.drawable.Drawable thumb) { throw new RuntimeException("Stub!"); }
public  int getThumbOffset() { throw new RuntimeException("Stub!"); }
public  void setThumbOffset(int thumbOffset) { throw new RuntimeException("Stub!"); }
public  void setKeyProgressIncrement(int increment) { throw new RuntimeException("Stub!"); }
public  int getKeyProgressIncrement() { throw new RuntimeException("Stub!"); }
public synchronized  void setMax(int max) { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void jumpDrawablesToCurrentState() { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected synchronized  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
protected synchronized  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
public  boolean onTouchEvent(android.view.MotionEvent event) { throw new RuntimeException("Stub!"); }
public  boolean onKeyDown(int keyCode, android.view.KeyEvent event) { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/widget/AbsSeekBar.java <==
package android.widget;
public abstract class AbsSeekBar
  extends android.widget.ProgressBar
{
public  AbsSeekBar(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AbsSeekBar(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  AbsSeekBar(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setThumb(android.graphics.drawable.Drawable thumb) { throw new RuntimeException("Stub!"); }
public  android.graphics.drawable.Drawable getThumb() { throw new RuntimeException("Stub!"); }
public  int getThumbOffset() { throw new RuntimeException("Stub!"); }
public  void setThumbOffset(int thumbOffset) { throw new RuntimeException("Stub!"); }
public  void setKeyProgressIncrement(int increment) { throw new RuntimeException("Stub!"); }
public  int getKeyProgressIncrement() { throw new RuntimeException("Stub!"); }
public synchronized  void setMax(int max) { throw new RuntimeException("Stub!"); }
protected  boolean verifyDrawable(android.graphics.drawable.Drawable who) { throw new RuntimeException("Stub!"); }
public  void jumpDrawablesToCurrentState() { throw new RuntimeException("Stub!"); }
protected  void drawableStateChanged() { throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected synchronized  void onDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
protected synchronized  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
public  boolean onTouchEvent(android.view.MotionEvent event) { throw new RuntimeException("Stub!"); }
public  boolean onKeyDown(int keyCode, android.view.KeyEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityNodeInfo(android.view.accessibility.AccessibilityNodeInfo info) { throw new RuntimeException("Stub!"); }
public  boolean performAccessibilityAction(int action, android.os.Bundle arguments) { throw new RuntimeException("Stub!"); }
}
